==> nextcloud-29.0.10.tgz: nextcloud/apps/password_policy/l10n/ug.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "پارولنىڭ ۋاقتى ئۆتۈپ كەتتى ، ئۇنتۇپ قالغان پارول ئۇسۇلىنى قايتا تەڭشەڭ",
    "Password must not have been used recently before." : "پارول يېقىندا ئىشلىتىلمىگەن بولۇشى كېرەك.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "پارول ئەڭ كۆپ ئۇچرايدىغان 1،000،000 نىڭ ئىچىدە. ئۇنى خاسلاشتۇرۇڭ.",
    "Password is present in compromised password list. Please choose a different password." : "پارول بۇزۇلغان پارول تىزىملىكىدە بار. باشقا پارولنى تاللاڭ.",
    "Password needs to be at least %s characters long." : "پارول كەم دېگەندە% s ھەرپ بولۇشى كېرەك.",
    "Password needs to contain at least one numeric character." : "پارول كەم دېگەندە بىر رەقەملىك ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password needs to contain at least one special character." : "پارول كەم دېگەندە بىر ئالاھىدە ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password needs to contain at least one lower and one upper case character." : "پارول كەم دېگەندە بىر تۆۋەن ۋە بىر چوڭ ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password policy" : "پارول سىياسىتى",
    "Allows admins to configure a password policy" : "باشقۇرغۇچىلارنىڭ پارول سىياسىتىنى تەڭشىشىگە يول قويىدۇ",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "باشقۇرغۇچىنىڭ پارولنىڭ بەزى ئالدىنقى شەرتلىرىنى ئېنىقلىشىغا يول قويۇڭ ، مەسىلەن. ئەڭ تۆۋەن ئۇزۇنلۇقنى ئىجرا قىلىڭ",
    "Minimum password length" : "ئەڭ تۆۋەن پارول ئۇزۇنلۇقى",
    "User password history" : "ئىشلەتكۈچى پارول تارىخى",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "قولدا ھەرىكەت قوللانمىغۇچە ئىشلەتكۈچى ھېساباتىدىن بۇرۇن كىرىش قېتىم سانى چەكلىنىدۇ. (0 چەكسىز)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "دىققەت قىلىڭ ، بۇ تاللاش ھۇجۇم قىلىنغان ھېساباتلارنى قوغداشنى مەقسەت قىلىدۇ. چەكلەنگەن ھېساباتلارنى باشقۇرۇش ئارقىلىق قولدا قايتا قوزغىتىش كېرەك. ھېسابات مەخپىي نومۇرىنى پەرەز قىلماقچى بولغان ھۇجۇمچىلار IP ئادرېسىنى بۇ تەڭشەكتىن مۇستەقىل ھالدا رەھىمسىزلەرچە قوغداش تەرىپىدىن توسۇۋالىدۇ.",
    "Number of days until user password expires" : "ئىشلەتكۈچى پارولى توشقانغا قەدەر كۈن سانى",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "ئاگاھلاندۇرۇش: مەخپىي نومۇرنىڭ مۇددىتى توشۇش ھازىر بىر قانچە بىخەتەرلىك ئورگانلىرىنىڭ بىخەتەرلىك خەۋىپى دەپ قارىلىدۇ.",
    "Forbid common passwords" : "ئورتاق مەخپىي نومۇرنى مەنئى قىلىڭ",
    "Enforce upper and lower case characters" : "چوڭ ۋە كىچىك ھەرپلەرنى ئىشلىتىڭ",
    "Enforce numeric characters" : "رەقەملىك ھەرپلەرنى ئىجرا قىلىڭ",
    "Enforce special characters" : "ئالاھىدە ھەرپلەرنى ئىجرا قىلىڭ",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Haveibeenpwned.com دىكى پارولنىڭ بۇزۇلغان پارول تىزىملىكىگە قارشى پارولنى تەكشۈرۈڭ",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "بۇ تەكشۈرۈش پارولنىڭ ھەش-پەش دېگۈسىنى ھاسىل قىلىدۇ ۋە بۇ ھاشنىڭ ئالدىنقى 5 ھەرپلىرىنى haveibeenpwned.com API غا ئەۋەتىپ ، شۇلاردىن باشلانغان بارلىق ئالدىراشلارنىڭ تىزىملىكىنى ئالىدۇ. ئاندىن Nextcloud مىسالىدا پارول hash نىڭ نەتىجە توپلىمى بار-يوقلۇقىنى تەكشۈرىدۇ.",
    "Unknown error" : "يوچۇن خاتالىق",
    "Minimal length has to be a non negative number" : "ئەڭ كىچىك ئۇزۇنلۇق مەنپىي بولمىغان سان بولۇشى كېرەك",
    "History size has to be a non negative number" : "تارىخنىڭ چوڭلۇقى مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Expiration days have to be a non negative number" : "مۇددىتى توشقان كۈنلەر مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Maximum login attempts have to be a non negative number" : "ئەڭ چوڭ كىرىش سىنىقى مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Settings saved" : "تەڭشەكلەر ساقلاندى",
    "Error while saving settings" : "تەڭشەكلەرنى ساقلاش جەريانىدا خاتالىق",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "دىققەت قىلىڭ ، بۇ تاللاش ھۇجۇم قىلىنغان ھېساباتلارنى قوغداشنى مەقسەت قىلىدۇ. چەكلەنگەن ھېساباتلارنى باشقۇرۇش ئارقىلىق قولدا قايتا قوزغىتىش كېرەك. ھېسابات مەخپىي نومۇرىنى پەرەز قىلماقچى بولغان ھۇجۇمچىلار IP ئادرېسىنى بۇ تەڭشەكتىن مۇستەقىل ھالدا رەھىمسىزلەرچە قوغداش تەرىپىدىن توسۇۋالىدۇ."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/password_policy/l10n/ug.js <==
OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "پارولنىڭ ۋاقتى ئۆتۈپ كەتتى ، ئۇنتۇپ قالغان پارول ئۇسۇلىنى قايتا تەڭشەڭ",
    "Password must not have been used recently before." : "پارول يېقىندا ئىشلىتىلمىگەن بولۇشى كېرەك.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "پارول ئەڭ كۆپ ئۇچرايدىغان 1،000،000 نىڭ ئىچىدە. ئۇنى خاسلاشتۇرۇڭ.",
    "Password is present in compromised password list. Please choose a different password." : "پارول بۇزۇلغان پارول تىزىملىكىدە بار. باشقا پارولنى تاللاڭ.",
    "Password needs to be at least %s characters long." : "پارول كەم دېگەندە% s ھەرپ بولۇشى كېرەك.",
    "Password needs to contain at least one numeric character." : "پارول كەم دېگەندە بىر رەقەملىك ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password needs to contain at least one special character." : "پارول كەم دېگەندە بىر ئالاھىدە ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password needs to contain at least one lower and one upper case character." : "پارول كەم دېگەندە بىر تۆۋەن ۋە بىر چوڭ ھەرپنى ئۆز ئىچىگە ئېلىشى كېرەك.",
    "Password policy" : "پارول سىياسىتى",
    "Allows admins to configure a password policy" : "باشقۇرغۇچىلارنىڭ پارول سىياسىتىنى تەڭشىشىگە يول قويىدۇ",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "باشقۇرغۇچىنىڭ پارولنىڭ بەزى ئالدىنقى شەرتلىرىنى ئېنىقلىشىغا يول قويۇڭ ، مەسىلەن. ئەڭ تۆۋەن ئۇزۇنلۇقنى ئىجرا قىلىڭ",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "قولدا ھەرىكەت قوللانمىغۇچە ئىشلەتكۈچى ھېساباتىدىن بۇرۇن كىرىش قېتىم سانى چەكلىنىدۇ. (0 چەكسىز)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "دىققەت قىلىڭ ، بۇ تاللاش ھۇجۇم قىلىنغان ھېساباتلارنى قوغداشنى مەقسەت قىلىدۇ. چەكلەنگەن ھېساباتلارنى باشقۇرۇش ئارقىلىق قولدا قايتا قوزغىتىش كېرەك. ھېسابات مەخپىي نومۇرىنى پەرەز قىلماقچى بولغان ھۇجۇمچىلار IP ئادرېسىنى بۇ تەڭشەكتىن مۇستەقىل ھالدا رەھىمسىزلەرچە قوغداش تەرىپىدىن توسۇۋالىدۇ.",
    "Number of days until user password expires" : "ئىشلەتكۈچى پارولى توشقانغا قەدەر كۈن سانى",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "ئاگاھلاندۇرۇش: مەخپىي نومۇرنىڭ مۇددىتى توشۇش ھازىر بىر قانچە بىخەتەرلىك ئورگانلىرىنىڭ بىخەتەرلىك خەۋىپى دەپ قارىلىدۇ.",
    "Minimum password length" : "ئەڭ تۆۋەن پارول ئۇزۇنلۇقى",
    "Forbid common passwords" : "ئورتاق مەخپىي نومۇرنى مەنئى قىلىڭ",
    "Enforce upper and lower case characters" : "چوڭ ۋە كىچىك ھەرپلەرنى ئىشلىتىڭ",
    "Enforce numeric characters" : "رەقەملىك ھەرپلەرنى ئىجرا قىلىڭ",
    "Enforce special characters" : "ئالاھىدە ھەرپلەرنى ئىجرا قىلىڭ",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Haveibeenpwned.com دىكى پارولنىڭ بۇزۇلغان پارول تىزىملىكىگە قارشى پارولنى تەكشۈرۈڭ",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "بۇ تەكشۈرۈش پارولنىڭ ھەش-پەش دېگۈسىنى ھاسىل قىلىدۇ ۋە بۇ ھاشنىڭ ئالدىنقى 5 ھەرپلىرىنى haveibeenpwned.com API غا ئەۋەتىپ ، شۇلاردىن باشلانغان بارلىق ئالدىراشلارنىڭ تىزىملىكىنى ئالىدۇ. ئاندىن Nextcloud مىسالىدا پارول hash نىڭ نەتىجە توپلىمى بار-يوقلۇقىنى تەكشۈرىدۇ.",
    "User password history" : "ئىشلەتكۈچى پارول تارىخى",
    "Please note, that this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "دىققەت قىلىڭ ، بۇ تاللاش ھۇجۇم قىلىنغان ھېساباتلارنى قوغداشنى مەقسەت قىلىدۇ. چەكلەنگەن ھېساباتلارنى باشقۇرۇش ئارقىلىق قولدا قايتا قوزغىتىش كېرەك. ھېسابات مەخپىي نومۇرىنى پەرەز قىلماقچى بولغان ھۇجۇمچىلار IP ئادرېسىنى بۇ تەڭشەكتىن مۇستەقىل ھالدا رەھىمسىزلەرچە قوغداش تەرىپىدىن توسۇۋالىدۇ.",
    "Unknown error" : "يوچۇن خاتالىق",
    "Minimal length has to be a non negative number" : "ئەڭ كىچىك ئۇزۇنلۇق مەنپىي بولمىغان سان بولۇشى كېرەك",
    "History size has to be a non negative number" : "تارىخنىڭ چوڭلۇقى مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Expiration days have to be a non negative number" : "مۇددىتى توشقان كۈنلەر مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Maximum login attempts have to be a non negative number" : "ئەڭ چوڭ كىرىش سىنىقى مەنپىي بولمىغان سان بولۇشى كېرەك",
    "Settings saved" : "تەڭشەكلەر ساقلاندى",
    "Error while saving settings" : "تەڭشەكلەرنى ساقلاش جەريانىدا خاتالىق"
},
"nplurals=2; plural=(n != 1);");
